/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef LIBPOLYXMASS_MONOMERSPEC_H
#define LIBPOLYXMASS_MONOMERSPEC_H


#include "libpolyxmass-globals.h"



typedef struct _PxmMonomerSpec PxmMonomerSpec;


enum
  {
    ERR_MNMSPEC_NOERR,
    ERR_MNMSPEC_NO_CODE,
    ERR_MNMSPEC_CODE_BUT_NO_MODIF,
    ERR_MNMSPEC_NO_VECTOR_FILE,
    ERR_MNMSPEC_NO_RASTER_FILE,
    ERR_MNMSPEC_NO_VECTOR_NOR_RASTER_FILES
  };


enum
  {
    FILE_VECTOR,
    FILE_RASTER,
    FILE_NONE,
    FILE_ANY,
    FILE_BOTH
  };



struct _PxmMonomerSpec
{
  /* 
     Full path+name of the raster graphic file (png or jpg, for
     example),

     /usr/share/polyxmass/polchem-defs/protein/glycine.png
  */
  gchar *raster;
  
  /* 
     Full path+name of the vector graphic file (svg), like for example,

     /usr/share/polyxmass/polchem-defs/protein/glycine.svg
   */
  gchar *vector;

  /* 
     Code of the monomer to which the graphic file is associated.
   */
  gchar *code;

  /* 
     Name of the modif to which the graphic file is associated.
   */
  gchar *modif;

  /* 
     Graphical action to be performed using the graphic file (upon
     modification of a monomer).
   */
  gchar *action;
};





/* NEW'ING FUNCTIONS, DUPLICATING FUNCTIONS ...
 */
PxmMonomerSpec *
libpolyxmass_monomerspec_new (void);

gboolean
libpolyxmass_monomerspec_set_raster (PxmMonomerSpec *ms, gchar *file);

gboolean
libpolyxmass_monomerspec_set_vector (PxmMonomerSpec *ms, gchar *file);

gboolean
libpolyxmass_monomerspec_set_code (PxmMonomerSpec *ms, gchar *code);

gboolean
libpolyxmass_monomerspec_set_modif (PxmMonomerSpec *ms, gchar *modif);

gboolean
libpolyxmass_monomerspec_set_action (PxmMonomerSpec *ms, gchar *action);





/*  LOCATING FUNCTIONS
 */
PxmMonomerSpec *
libpolyxmass_monomerspec_get_ptr_by_code_modif (gchar *code, 
						gchar* modif,
						gint check, 
						GPtrArray *GPA,
						gint *error);
gint
libpolyxmass_monomerspec_get_index_by_code (GPtrArray *GPA, 
					    gchar *code);

gint
libpolyxmass_monomerspec_get_index_top_by_code (GPtrArray *GPA, 
						gchar *code);

gint
libpolyxmass_monomerspec_get_index_bottom_by_code (GPtrArray *GPA, 
						   gchar *code);

gint
libpolyxmass_monomerspec_get_index_by_modif (GPtrArray *GPA, 
					     gchar *modif);

gint
libpolyxmass_monomerspec_get_index_top_by_modif (GPtrArray *GPA, 
						 gchar *modif);

gint
libpolyxmass_monomerspec_get_index_bottom_by_modif (GPtrArray *GPA, 
						gchar *modif);




/* UTILITY FUNCTIONS
 */
gboolean
libpolyxmass_monomerspec_reset (PxmMonomerSpec *ms);

/* 
   The monomer-modif.dic file.
*/
PxmMonomerSpec *
libpolyxmass_monomerspec_init_from_dic_mnm_line (gchar *line, 
						 gchar *dir);


PxmMonomerSpec *
libpolyxmass_monomerspec_init_from_dic_mdf_line (gchar *line, 
						 gchar *dir);

gint
libpolyxmass_monomerspec_parse_dic_file (gchar *file,
					 GPtrArray *GPA);




/* FREE'ING FUNCTIONS
 */
gint
libpolyxmass_monomerspec_free (PxmMonomerSpec *ms);





/* GPtrArray-RELATED FUNCTIONS
 */
gint
libpolyxmass_monomerspec_GPA_empty (GPtrArray *GPA);

gint
libpolyxmass_monomerspec_GPA_free (GPtrArray *GPA);
















#endif
/*
  #ifndef LIBPOLYXMASS_MONOMERSPEC_H
*/



